@@ -101,12 +101,14 @@ PrimeFactory::PrimeFactory (const String &lang,
                             const ConfigPointer &config)
     : m_uuid (uuid),
       m_config (config),
-      m_predict_on_preedition (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
-      m_auto_register (SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT),
       m_commit_on_upper (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT),
+      m_predict_on_preedition (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT),
+      m_inline_prediction (SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT),
+      m_auto_register (SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT),
       m_close_cand_win_on_select (SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT),
       m_show_annotation (SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT),
-      m_show_usage (SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT)
+      m_show_usage (SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT),
+      m_show_comment (SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT)
 {
     SCIM_DEBUG_IMENGINE(1) << "Create PRIME Factory :\n";
     SCIM_DEBUG_IMENGINE(1) << "  Lang : " << lang << "\n";
@@ -188,15 +190,23 @@ PrimeFactory::reload_config (const ConfigPointer &config)
     m_typing_method
         = config->read (String (SCIM_PRIME_CONFIG_TYPING_METHOD),
                         String (SCIM_PRIME_CONFIG_TYPING_METHOD_DEFAULT));
-    m_predict_on_preedition
-        = config->read (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
-                        SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT);
-    m_auto_register
-        = config->read (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
-                        SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT);
     m_commit_on_upper
         = config->read (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                         SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT);
+
+    m_predict_on_preedition
+        = config->read (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
+                        SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT);
+    m_direct_select_on_prediction
+        = config->read (String (SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION),
+                        SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT);
+    m_inline_prediction
+        = config->read (String (SCIM_PRIME_CONFIG_INLINE_PREDICTION),
+                        SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT);
+
+    m_auto_register
+        = config->read (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
+                        SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT);
     m_close_cand_win_on_select
         = config->read (String (SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT),
                         SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT);
@@ -206,6 +216,9 @@ PrimeFactory::reload_config (const ConfigPointer &config)
     m_show_usage
         = config->read (String (SCIM_PRIME_CONFIG_SHOW_USAGE),
                         SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT);
+    m_show_comment
+        = config->read (String (SCIM_PRIME_CONFIG_SHOW_COMMENT),
+                        SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT);
     m_space_char
         = config->read (String (SCIM_PRIME_CONFIG_SPACE_CHAR),
                         String (SCIM_PRIME_CONFIG_SPACE_CHAR_DEFAULT));
@@ -216,14 +229,16 @@ PrimeFactory::reload_config (const ConfigPointer &config)
     m_actions.clear ();
 
     // edit keys
-    APPEND_ACTION (COMMIT,                  action_commit_with_learn);
-    APPEND_ACTION (COMMIT_WITHOUT_LEARN,    action_commit_without_learn);
-    APPEND_ACTION (CONVERT,                 action_convert);
-    APPEND_ACTION (CANCEL,                  action_revert);
-    APPEND_ACTION (BACKSPACE,               action_edit_backspace);
-    APPEND_ACTION (DELETE,                  action_edit_delete);
     APPEND_ACTION (SPACE,                   action_insert_space);
     APPEND_ACTION (ALTERNATIVE_SPACE,       action_insert_alternative_space);
+    APPEND_ACTION (COMMIT,                  action_commit_with_learn);
+    APPEND_ACTION (COMMIT_WITHOUT_LEARN,    action_commit_without_learn);
+    APPEND_ACTION (COMMIT_ALTERNATIVE,      action_commit_alternative);
+    APPEND_ACTION (CONVERT,                 action_convert);
+    APPEND_ACTION (CANCEL,                  action_revert);
+    APPEND_ACTION (SELECT_PREDICTION,       action_start_selecting_prediction);
+    APPEND_ACTION (BACKSPACE,               action_edit_backspace);
+    APPEND_ACTION (DELETE,                  action_edit_delete);
 
     // caret keys
     APPEND_ACTION (MODIFY_CARET_LEFT,       action_modify_caret_left);
@@ -247,6 +262,14 @@ PrimeFactory::reload_config (const ConfigPointer &config)
     APPEND_ACTION (SELECT_CANDIDATE_9,      action_select_candidate_9);
     APPEND_ACTION (SELECT_CANDIDATE_10,     action_select_candidate_10);
 
+    // segment keys
+	APPEND_ACTION (SELECT_FIRST_SEGMENT,    action_select_first_segment);
+	APPEND_ACTION (SELECT_LAST_SEGMENT,     action_select_last_segment);
+	APPEND_ACTION (SELECT_NEXT_SEGMENT,     action_select_next_segment);
+	APPEND_ACTION (SELECT_PREV_SEGMENT,     action_select_prev_segment);
+	APPEND_ACTION (SHRINK_SEGMENT,          action_shrink_segment);
+	APPEND_ACTION (EXPAND_SEGMENT,          action_expand_segment);
+
     // mode keys
     APPEND_ACTION (SET_MODE_DEFAULT,        action_set_mode_default);
     APPEND_ACTION (SET_MODE_KATAKANA,       action_set_mode_katakana);
