@@ -130,60 +130,48 @@ struct ComboConfigData
 };
 
 // Internal data declaration.
-static String __config_command                  = SCIM_PRIME_CONFIG_COMMAND_DEFAULT;
-static bool   __config_predict_on_preedition    = SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT;
-static bool   __config_auto_register            = SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT;
-static bool   __config_commit_on_upper          = SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT;
-static bool   __config_close_cand_win_on_select = SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT;
-static bool   __config_show_annotation          = SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT;
-static bool   __config_show_usage               = SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT;
+static String __config_command                     = SCIM_PRIME_CONFIG_COMMAND_DEFAULT;
+static bool   __config_commit_on_upper             = SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT;
+static bool   __config_predict_on_preedition       = SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT;
+static bool   __config_direct_select_on_prediction = SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT;
+static bool   __config_inline_prediction           = SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT;
+static bool   __config_auto_register               = SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT;
+static bool   __config_close_cand_win_on_select    = SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT;
+static bool   __config_show_annotation             = SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT;
+static bool   __config_show_usage                  = SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT;
+static bool   __config_show_comment                = SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT;
 
 static bool __have_changed    = true;
 
-static GtkWidget    * __widget_command                  = 0;
-static GtkWidget    * __widget_predict_on_preedition    = 0;
-static GtkWidget    * __widget_auto_register            = 0;
-static GtkWidget    * __widget_commit_on_upper          = 0;
-static GtkWidget    * __widget_close_cand_win_on_select = 0;
-static GtkWidget    * __widget_show_annotation          = 0;
-static GtkWidget    * __widget_show_usage               = 0;
-static GtkTooltips  * __widget_tooltips                 = 0;
+static GtkWidget    * __widget_command                     = 0;
+static GtkWidget    * __widget_commit_on_upper             = 0;
+static GtkWidget    * __widget_predict_on_preedition       = 0;
+static GtkWidget    * __widget_direct_select_on_prediction = 0;
+static GtkWidget    * __widget_inline_prediction           = 0;
+static GtkWidget    * __widget_auto_register               = 0;
+static GtkWidget    * __widget_close_cand_win_on_select    = 0;
+static GtkWidget    * __widget_show_annotation             = 0;
+static GtkWidget    * __widget_show_usage                  = 0;
+static GtkWidget    * __widget_show_comment                = 0;
+static GtkTooltips  * __widget_tooltips                    = 0;
 
-static KeyboardConfigData __config_keyboards_common [] =
+static KeyboardConfigData __config_keyboards_edit [] =
 {
     {
-        SCIM_PRIME_CONFIG_COMMIT_KEY,
-        SCIM_PRIME_CONFIG_COMMIT_KEY_DEFAULT,
-        N_("Commit keys:"),
-        N_("Select commit keys"),
-        N_("The key events to commit the preedit string. "),
+        SCIM_PRIME_CONFIG_SPACE_KEY,
+        SCIM_PRIME_CONFIG_SPACE_KEY_DEFAULT,
+        N_("Space keys:"),
+        N_("Select space keys"),
+        N_("The key events to insert space letter on non-preediting state. "),
         NULL,
         NULL,
     },
     {
-        SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY,
-        SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY_DEFAULT,
-        N_("Commit witout learn keys:"),
-        N_("Select commit witout learn keys"),
-        N_("The key events to commit the preedit string without learn. "),
-        NULL,
-        NULL,
-    },
-    {
-        SCIM_PRIME_CONFIG_CONVERT_KEY,
-        SCIM_PRIME_CONFIG_CONVERT_KEY_DEFAULT,
-        N_("Convert keys:"),
-        N_("Select convert keys"),
-        N_("The key events to convert the preedit string to kanji. "),
-        NULL,
-        NULL,
-    },
-    {
-        SCIM_PRIME_CONFIG_CANCEL_KEY,
-        SCIM_PRIME_CONFIG_CANCEL_KEY_DEFAULT,
-        N_("Cancel keys:"),
-        N_("Select cancel keys"),
-        N_("The key events to cancel preediting or converting. "),
+        SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_KEY,
+        SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_KEY_DEFAULT,
+        N_("Alternative space keys:"),
+        N_("Select alternative space keys"),
+        N_("The key events to insert alterenative space letter on non-preediting state. "),
         NULL,
         NULL,
     },
@@ -206,20 +194,70 @@ static KeyboardConfigData __config_keyboards_common [] =
         NULL,
     },
     {
-        SCIM_PRIME_CONFIG_SPACE_KEY,
-        SCIM_PRIME_CONFIG_SPACE_KEY_DEFAULT,
-        N_("Space keys:"),
-        N_("Select space keys"),
-        N_("The key events to insert space letter on non-preediting state. "),
+        NULL,
+        "",
+        NULL,
+        NULL,
+        NULL,
+        NULL,
+        NULL,
+    },
+};
+
+static KeyboardConfigData __config_keyboards_convert [] =
+{
+    {
+        SCIM_PRIME_CONFIG_CONVERT_KEY,
+        SCIM_PRIME_CONFIG_CONVERT_KEY_DEFAULT,
+        N_("Convert keys:"),
+        N_("Select convert keys"),
+        N_("The key events to convert the preedit string to kanji. "),
         NULL,
         NULL,
     },
     {
-        SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_KEY,
-        SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_KEY_DEFAULT,
-        N_("Alternative space keys:"),
-        N_("Select alternative space keys"),
-        N_("The key events to insert alterenative space letter on non-preediting state. "),
+        SCIM_PRIME_CONFIG_CANCEL_KEY,
+        SCIM_PRIME_CONFIG_CANCEL_KEY_DEFAULT,
+        N_("Cancel keys:"),
+        N_("Select cancel keys"),
+        N_("The key events to cancel preediting or converting. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_COMMIT_KEY,
+        SCIM_PRIME_CONFIG_COMMIT_KEY_DEFAULT,
+        N_("Commit keys:"),
+        N_("Select commit keys"),
+        N_("The key events to commit the preedit string. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY,
+        SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY_DEFAULT,
+        N_("Commit witout learn keys:"),
+        N_("Select commit witout learn keys"),
+        N_("The key events to commit the preedit string without learn. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_COMMIT_ALTERNATIVE_KEY,
+        SCIM_PRIME_CONFIG_COMMIT_ALTERNATIVE_KEY_DEFAULT,
+        N_("Alternative commit keys:"),
+        N_("Select alternative commit keys"),
+        N_("The key events to commit the first predicted string. "
+           "On inline prediction mode, reading string will be commited by this key events."),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_SELECT_PREDICTION_KEY,
+        SCIM_PRIME_CONFIG_SELECT_PREDICTION_KEY_DEFAULT,
+        N_("Complete keys:"),
+        N_("Select complete keys"),
+        N_("The key events to complete a word using predictions. "),
         NULL,
         NULL,
     },
@@ -359,6 +397,73 @@ static KeyboardConfigData __config_keyboards_caret [] =
     },
 };
 
+static KeyboardConfigData __config_keyboards_segments [] =
+{
+    {
+        SCIM_PRIME_CONFIG_SELECT_FIRST_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_SELECT_FIRST_SEGMENT_KEY_DEFAULT,
+        N_("First segment keys:"),
+        N_("Select first segment keys"),
+        N_("The key events to select first segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_SELECT_LAST_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_SELECT_LAST_SEGMENT_KEY_DEFAULT,
+        N_("Last segment keys:"),
+        N_("Select last segment keys"),
+        N_("The key events to select last segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_SELECT_NEXT_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_SELECT_NEXT_SEGMENT_KEY_DEFAULT,
+        N_("Next segment keys:"),
+        N_("Select next segment keys"),
+        N_("The key events to select next segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_SELECT_PREV_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_SELECT_PREV_SEGMENT_KEY_DEFAULT,
+        N_("Previous segment keys:"),
+        N_("Select previous segment keys"),
+        N_("The key events to select previous segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_SHRINK_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_SHRINK_SEGMENT_KEY_DEFAULT,
+        N_("Shrink segment keys:"),
+        N_("Select shrink segment keys"),
+        N_("The key events to shrink the selected segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        SCIM_PRIME_CONFIG_EXPAND_SEGMENT_KEY,
+        SCIM_PRIME_CONFIG_EXPAND_SEGMENT_KEY_DEFAULT,
+        N_("Expand segment keys:"),
+        N_("Select expand segment keys"),
+        N_("The key events to expand the selected segment. "),
+        NULL,
+        NULL,
+    },
+    {
+        NULL,
+        "",
+        NULL,
+        NULL,
+        NULL,
+        NULL,
+        NULL,
+    },
+};
+
 static KeyboardConfigData __config_keyboards_candidates [] =
 {
     {
@@ -513,10 +618,11 @@ static KeyboardConfigData __config_keyboards_direct_select_candidate [] =
 
 static struct KeyboardConfigPage __key_conf_pages[] =
 {
-    {N_("Common keys"),     __config_keyboards_common},
+    {N_("Edit keys"),       __config_keyboards_edit},
+    {N_("Convert keys"),    __config_keyboards_convert},
     {N_("Mode keys"),       __config_keyboards_mode},
     {N_("Caret keys"),      __config_keyboards_caret},
-    //{N_("Segments keys"),   __config_keyboards_segments},
+    {N_("Segments keys"),   __config_keyboards_segments},
     {N_("Candidates keys"), __config_keyboards_candidates},
     {N_("Candidates keys (Direct select)"), __config_keyboards_direct_select_candidate},
 };
@@ -606,24 +712,6 @@ create_options_page ()
     APPEND_ENTRY(_("PRIME command:"), _("The PRIME command to use as conversion engine."),
                  __widget_command, 0);
 
-    /* predict on preedition */
-    __widget_predict_on_preedition
-        = gtk_check_button_new_with_mnemonic (_("Predict while typing letters."));
-    gtk_widget_show (__widget_predict_on_preedition);
-    gtk_box_pack_start (GTK_BOX (vbox), __widget_predict_on_preedition, FALSE, FALSE, 4);
-    gtk_container_set_border_width (GTK_CONTAINER (__widget_predict_on_preedition), 4);
-    gtk_tooltips_set_tip (__widget_tooltips, __widget_predict_on_preedition,
-                          _("Predict while typing letters."), NULL);
-
-    /* auto register */
-    __widget_auto_register
-        = gtk_check_button_new_with_mnemonic (_("Use auto registering a word feature"));
-    gtk_widget_show (__widget_auto_register);
-    gtk_box_pack_start (GTK_BOX (vbox), __widget_auto_register, FALSE, FALSE, 4);
-    gtk_container_set_border_width (GTK_CONTAINER (__widget_auto_register), 4);
-    gtk_tooltips_set_tip (__widget_tooltips, __widget_auto_register,
-                          _("Invoke the registering a word mode when the cursor in the candidates window is move to out of range."), NULL);
-
     /* commit on upper */
     __widget_commit_on_upper
         = gtk_check_button_new_with_mnemonic (_("Commit on inputting upper letter"));
@@ -633,6 +721,97 @@ create_options_page ()
     gtk_tooltips_set_tip (__widget_tooltips, __widget_commit_on_upper,
                           _("Commit previous preedit string when a upper letter is entered."), NULL);
 
+    // Connect all signals.
+    g_signal_connect ((gpointer) __widget_command, "changed",
+                      G_CALLBACK (on_default_editable_changed),
+                      &__config_command);
+    g_signal_connect ((gpointer) __widget_commit_on_upper, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_commit_on_upper);
+
+    return vbox;
+}
+
+static GtkWidget *
+create_prediction_page ()
+{
+    GtkWidget *vbox, *table;
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox);
+
+    table = gtk_table_new (2, 2, FALSE);
+    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 4);
+    gtk_widget_show (table);
+
+    if (!__widget_tooltips)
+        __widget_tooltips = gtk_tooltips_new();
+
+    /* predict on preedition */
+    __widget_predict_on_preedition
+        = gtk_check_button_new_with_mnemonic (_("Predict while typing letters."));
+    gtk_widget_show (__widget_predict_on_preedition);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_predict_on_preedition, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_predict_on_preedition), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_predict_on_preedition,
+                          _("Show candidates window to display predicted candidates while typing letters."), NULL);
+
+    /* use direct select keys on prediction */
+    __widget_direct_select_on_prediction
+        = gtk_check_button_new_with_mnemonic (_("Use direct select keys also on prediction."));
+    gtk_widget_show (__widget_direct_select_on_prediction);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_direct_select_on_prediction, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_direct_select_on_prediction), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_direct_select_on_prediction,
+                          _("Use direct select keys not only for conversion state but also for prediction state."), NULL);
+
+    /* use direct select keys on prediction */
+    __widget_inline_prediction
+        = gtk_check_button_new_with_mnemonic (_("Inline prediction."));
+    gtk_widget_show (__widget_inline_prediction);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_inline_prediction, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_inline_prediction), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_inline_prediction,
+                          _("Show first candidate of predictions instead of reading on preedit area. Reading is shown by external window."), NULL);
+
+    // Connect all signals.
+    g_signal_connect ((gpointer) __widget_predict_on_preedition, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_predict_on_preedition);
+    g_signal_connect ((gpointer) __widget_direct_select_on_prediction, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_direct_select_on_prediction);
+    g_signal_connect ((gpointer) __widget_inline_prediction, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_inline_prediction);
+
+    return vbox;
+}
+
+static GtkWidget *
+create_candidates_window_page ()
+{
+    GtkWidget *vbox, *table;
+
+    vbox = gtk_vbox_new (FALSE, 0);
+    gtk_widget_show (vbox);
+
+    table = gtk_table_new (2, 2, FALSE);
+    gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 4);
+    gtk_widget_show (table);
+
+    if (!__widget_tooltips)
+        __widget_tooltips = gtk_tooltips_new();
+
+    /* auto register */
+    __widget_auto_register
+        = gtk_check_button_new_with_mnemonic (_("Change to inline word register mode automatically."));
+    gtk_widget_show (__widget_auto_register);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_auto_register, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_auto_register), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_auto_register,
+                          _("Invoke the inline word register mode when the cursor in the candidates window is move to out of range."), NULL);
+
     /* close candidate window on select */
     __widget_close_cand_win_on_select
         = gtk_check_button_new_with_mnemonic (_("Close candidates window when a candidate is selected directly."));
@@ -649,30 +828,30 @@ create_options_page ()
     gtk_box_pack_start (GTK_BOX (vbox), __widget_show_annotation, FALSE, FALSE, 4);
     gtk_container_set_border_width (GTK_CONTAINER (__widget_show_annotation), 4);
     gtk_tooltips_set_tip (__widget_tooltips, __widget_show_annotation,
-                          _("Show annotation of the word on candidates window."), NULL);
+                          _("Show annotation of the word on the candidates window."), NULL);
 
-    /* show annotation */
+    /* show usage */
     __widget_show_usage
-        = gtk_check_button_new_with_mnemonic (_("Show usage of the word on candidates window"));
+        = gtk_check_button_new_with_mnemonic (_("Show usage of the word on the candidates window"));
     gtk_widget_show (__widget_show_usage);
     gtk_box_pack_start (GTK_BOX (vbox), __widget_show_usage, FALSE, FALSE, 4);
     gtk_container_set_border_width (GTK_CONTAINER (__widget_show_usage), 4);
     gtk_tooltips_set_tip (__widget_tooltips, __widget_show_usage,
                           _("Show usage of the word on the candidates window."), NULL);
 
+    /* show comment */
+    __widget_show_comment
+        = gtk_check_button_new_with_mnemonic (_("Show comment of the word on the candidates window"));
+    gtk_widget_show (__widget_show_comment);
+    gtk_box_pack_start (GTK_BOX (vbox), __widget_show_comment, FALSE, FALSE, 4);
+    gtk_container_set_border_width (GTK_CONTAINER (__widget_show_comment), 4);
+    gtk_tooltips_set_tip (__widget_tooltips, __widget_show_comment,
+                          _("Show comment of the word on the candidates window."), NULL);
+
     // Connect all signals.
-    g_signal_connect ((gpointer) __widget_command, "changed",
-                      G_CALLBACK (on_default_editable_changed),
-                      &__config_command);
-    g_signal_connect ((gpointer) __widget_predict_on_preedition, "toggled",
-                      G_CALLBACK (on_default_toggle_button_toggled),
-                      &__config_predict_on_preedition);
     g_signal_connect ((gpointer) __widget_auto_register, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_auto_register);
-    g_signal_connect ((gpointer) __widget_commit_on_upper, "toggled",
-                      G_CALLBACK (on_default_toggle_button_toggled),
-                      &__config_commit_on_upper);
     g_signal_connect ((gpointer) __widget_close_cand_win_on_select, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_close_cand_win_on_select);
@@ -682,6 +861,9 @@ create_options_page ()
     g_signal_connect ((gpointer) __widget_show_usage, "toggled",
                       G_CALLBACK (on_default_toggle_button_toggled),
                       &__config_show_usage);
+    g_signal_connect ((gpointer) __widget_show_comment, "toggled",
+                      G_CALLBACK (on_default_toggle_button_toggled),
+                      &__config_show_comment);
 
     return vbox;
 }
@@ -769,24 +951,37 @@ create_setup_window ()
 
     if (!window) {
         GtkWidget *notebook = gtk_notebook_new();
+        gtk_notebook_popup_enable(GTK_NOTEBOOK(notebook));
         gtk_widget_show (notebook);
         window = notebook;
         gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
 
-        // Create the first page.
+        // Create the 1st page.
         GtkWidget *page = create_options_page ();
         GtkWidget *label = gtk_label_new (_("Options"));
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
+        // Create the 2nd page.
+        page = create_prediction_page ();
+        label = gtk_label_new (_("Prediction"));
+        gtk_widget_show (label);
+        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+
+        // Create the 3rd page.
+        page = create_candidates_window_page ();
+        label = gtk_label_new (_("Candidates window"));
+        gtk_widget_show (label);
+        gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
+
 #if 0
-        // Create the second page.
+        // Create the 4th page.
         page = create_toolbar_page ();
         label = gtk_label_new (_("Toolbar"));
         gtk_widget_show (label);
         gtk_notebook_append_page (GTK_NOTEBOOK (notebook), page, label);
 
-        // Create the third page.
+        // Create the 5th page.
         page = create_dict_page ();
         label = gtk_label_new (_("Dictionary"));
         gtk_widget_show (label);
@@ -841,42 +1036,53 @@ setup_widget_value ()
             GTK_ENTRY (__widget_command),
             __config_command.c_str ());
     }
+    if (__widget_commit_on_upper) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_commit_on_upper),
+            __config_commit_on_upper);
+    }
 
     if (__widget_predict_on_preedition) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_predict_on_preedition),
             __config_predict_on_preedition);
     }
+    if (__widget_direct_select_on_prediction) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_direct_select_on_prediction),
+            __config_direct_select_on_prediction);
+    }
+    if (__widget_inline_prediction) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_inline_prediction),
+            __config_inline_prediction);
+    }
 
     if (__widget_auto_register) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_auto_register),
             __config_auto_register);
     }
-
-    if (__widget_commit_on_upper) {
-        gtk_toggle_button_set_active (
-            GTK_TOGGLE_BUTTON (__widget_commit_on_upper),
-            __config_commit_on_upper);
-    }
-
     if (__widget_close_cand_win_on_select) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_close_cand_win_on_select),
             __config_close_cand_win_on_select);
     }
-
     if (__widget_show_annotation) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_show_annotation),
             __config_show_annotation);
     }
-
     if (__widget_show_usage) {
         gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (__widget_show_usage),
             __config_show_usage);
     }
+    if (__widget_show_comment) {
+        gtk_toggle_button_set_active (
+            GTK_TOGGLE_BUTTON (__widget_show_comment),
+            __config_show_comment);
+    }
 
     for (unsigned int j = 0; j < __key_conf_pages_num; ++j) {
         for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
@@ -898,15 +1104,23 @@ load_config (const ConfigPointer &config)
     __config_command =
         config->read (String (SCIM_PRIME_CONFIG_COMMAND),
                       __config_command);
-    __config_predict_on_preedition=
-        config->read (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
-                      __config_predict_on_preedition);
-    __config_auto_register =
-        config->read (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
-                      __config_auto_register);
     __config_commit_on_upper =
         config->read (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                       __config_commit_on_upper);
+
+    __config_predict_on_preedition=
+        config->read (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
+                      __config_predict_on_preedition);
+    __config_direct_select_on_prediction =
+        config->read (String (SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION),
+                      __config_direct_select_on_prediction);
+    __config_inline_prediction =
+        config->read (String (SCIM_PRIME_CONFIG_INLINE_PREDICTION),
+                      __config_inline_prediction);
+
+    __config_auto_register =
+        config->read (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
+                      __config_auto_register);
     __config_close_cand_win_on_select =
         config->read (String (SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT),
                       __config_close_cand_win_on_select);
@@ -916,6 +1130,9 @@ load_config (const ConfigPointer &config)
     __config_show_usage =
         config->read (String (SCIM_PRIME_CONFIG_SHOW_USAGE),
                       __config_show_usage);
+    __config_show_comment =
+        config->read (String (SCIM_PRIME_CONFIG_SHOW_COMMENT),
+                      __config_show_comment);
 
     for (unsigned int j = 0; j < __key_conf_pages_num; ++ j) {
         for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
@@ -938,18 +1155,26 @@ save_config (const ConfigPointer &config)
 
     config->write (String (SCIM_PRIME_CONFIG_COMMAND),
                    __config_command);
-    config->write (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
-                   __config_predict_on_preedition);
-    config->write (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
-                   __config_auto_register);
     config->write (String (SCIM_PRIME_CONFIG_COMMIT_ON_UPPER),
                    __config_commit_on_upper);
+
+    config->write (String (SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION),
+                   __config_predict_on_preedition);
+    config->write (String (SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION),
+                   __config_direct_select_on_prediction);
+    config->write (String (SCIM_PRIME_CONFIG_INLINE_PREDICTION),
+                   __config_inline_prediction);
+
+    config->write (String (SCIM_PRIME_CONFIG_AUTO_REGISTER),
+                   __config_auto_register);
     config->write (String (SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT),
                    __config_close_cand_win_on_select);
     config->write (String (SCIM_PRIME_CONFIG_SHOW_ANNOTATION),
                    __config_show_annotation);
     config->write (String (SCIM_PRIME_CONFIG_SHOW_USAGE),
                    __config_show_usage);
+    config->write (String (SCIM_PRIME_CONFIG_SHOW_COMMENT),
+                   __config_show_comment);
 
     for (unsigned int j = 0; j < __key_conf_pages_num; j++) {
         for (unsigned int i = 0; __key_conf_pages[j].data[i].key; ++ i) {
