@@ -23,19 +23,27 @@
 
 #define SCIM_PRIME_CONFIG_COMMAND                             "/IMEngine/PRIME/Command"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD                       "/IMEngine/PRIME/TypingMethod"
-#define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION               "/IMEngine/PRIME/PredictOnPreedition"
-#define SCIM_PRIME_CONFIG_AUTO_REGISTER                       "/IMEngine/PRIME/AutoRegister"
 #define SCIM_PRIME_CONFIG_COMMIT_ON_UPPER                     "/IMEngine/PRIME/CommitOnUpper"
+
+#define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION               "/IMEngine/PRIME/PredictOnPreedition"
+#define SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION         "/IMEngine/PRIME/DirectSelectOnPrediction"
+#define SCIM_PRIME_CONFIG_INLINE_PREDICTION                   "/IMEngine/PRIME/InlinePrediction"
+
+#define SCIM_PRIME_CONFIG_AUTO_REGISTER                       "/IMEngine/PRIME/AutoRegister"
 #define SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT            "/IMEngine/PRIME/CloseCandWinOnSelect"
 #define SCIM_PRIME_CONFIG_SHOW_ANNOTATION                     "/IMEngine/PRIME/ShowAnnotation"
 #define SCIM_PRIME_CONFIG_SHOW_USAGE                          "/IMEngine/PRIME/ShowUsage"
+#define SCIM_PRIME_CONFIG_SHOW_COMMENT                        "/IMEngine/PRIME/ShowComment"
+
 #define SCIM_PRIME_CONFIG_SPACE_CHAR                          "/IMEngine/PRIME/SpaceChar"
 #define SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_CHAR              "/IMEngine/PRIME/AlternativeSpaceChar"
 
 #define SCIM_PRIME_CONFIG_COMMIT_KEY                          "/IMEngine/PRIME/CommitKey"
 #define SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY            "/IMEngine/PRIME/CommitWithoutLearnKey"
+#define SCIM_PRIME_CONFIG_COMMIT_ALTERNATIVE_KEY              "/IMEngine/PRIME/CommitAlternativeKey"
 #define SCIM_PRIME_CONFIG_CONVERT_KEY                         "/IMEngine/PRIME/ConvertKey"
 #define SCIM_PRIME_CONFIG_CANCEL_KEY                          "/IMEngine/PRIME/CancelKey"
+#define SCIM_PRIME_CONFIG_SELECT_PREDICTION_KEY               "/IMEngine/PRIME/SelectPredictionKey"
 #define SCIM_PRIME_CONFIG_BACKSPACE_KEY                       "/IMEngine/PRIME/BackSpaceKey"
 #define SCIM_PRIME_CONFIG_DELETE_KEY                          "/IMEngine/PRIME/DeleteKey"
 #define SCIM_PRIME_CONFIG_SPACE_KEY                           "/IMEngine/PRIME/SpaceKey"
@@ -58,6 +66,12 @@
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_8_KEY              "/IMEngine/PRIME/SelectCandidates8Key"
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_9_KEY              "/IMEngine/PRIME/SelectCandidates9Key"
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_10_KEY             "/IMEngine/PRIME/SelectCandidates10Key"
+#define SCIM_PRIME_CONFIG_SELECT_FIRST_SEGMENT_KEY            "/IMEngine/PRIME/SelectFirstSegmentKey"
+#define SCIM_PRIME_CONFIG_SELECT_LAST_SEGMENT_KEY             "/IMEngine/PRIME/SelectLastSegmentKey"
+#define SCIM_PRIME_CONFIG_SELECT_NEXT_SEGMENT_KEY             "/IMEngine/PRIME/SelectNextSegmentKey"
+#define SCIM_PRIME_CONFIG_SELECT_PREV_SEGMENT_KEY             "/IMEngine/PRIME/SelectPrevSegmentKey"
+#define SCIM_PRIME_CONFIG_SHRINK_SEGMENT_KEY                  "/IMEngine/PRIME/ShrinkSegmentKey"
+#define SCIM_PRIME_CONFIG_EXPAND_SEGMENT_KEY                  "/IMEngine/PRIME/ExpandSegmentKey"
 #define SCIM_PRIME_CONFIG_SET_MODE_DEFAULT_KEY                "/IMEngine/PRIME/SetModeDefaultKey"
 #define SCIM_PRIME_CONFIG_SET_MODE_KATAKANA_KEY               "/IMEngine/PRIME/SetModeKatakanaKey"
 #define SCIM_PRIME_CONFIG_SET_MODE_HALF_KATAKANA_KEY          "/IMEngine/PRIME/SetModeHalfKatakanaKey"
@@ -68,19 +82,27 @@
 
 #define SCIM_PRIME_CONFIG_COMMAND_DEFAULT                     "prime"
 #define SCIM_PRIME_CONFIG_TYPING_METHOD_DEFAULT               ""
-#define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT       true
-#define SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT               false
+
+#define SCIM_PRIME_CONFIG_AUTO_REGISTER_DEFAULT               true
 #define SCIM_PRIME_CONFIG_COMMIT_ON_UPPER_DEFAULT             false
-#define SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT    false
+
+#define SCIM_PRIME_CONFIG_PREDICT_ON_PREEDITION_DEFAULT       true
+#define SCIM_PRIME_CONFIG_DIRECT_SELECT_ON_PREDICTION_DEFAULT true
+#define SCIM_PRIME_CONFIG_INLINE_PREDICTION_DEFAULT           false
+
+#define SCIM_PRIME_CONFIG_CLOSE_CAND_WIN_ON_SELECT_DEFAULT    true
 #define SCIM_PRIME_CONFIG_SHOW_ANNOTATION_DEFAULT             true
-#define SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT                  false
+#define SCIM_PRIME_CONFIG_SHOW_USAGE_DEFAULT                  true
+#define SCIM_PRIME_CONFIG_SHOW_COMMENT_DEFAULT                true
 #define SCIM_PRIME_CONFIG_SPACE_CHAR_DEFAULT                  " "
 #define SCIM_PRIME_CONFIG_ALTERNATIVE_SPACE_CHAR_DEFAULT      "\xE3\x80\x80"
 
 #define SCIM_PRIME_CONFIG_COMMIT_KEY_DEFAULT                  "Return,KP_Enter,Control+m,Control+M,Henkan"
 #define SCIM_PRIME_CONFIG_COMMIT_WITHOUT_LEARN_KEY_DEFAULT    "Muhenkan"
-#define SCIM_PRIME_CONFIG_CONVERT_KEY_DEFAULT                 "space,Control+l,Control+L"
+#define SCIM_PRIME_CONFIG_COMMIT_ALTERNATIVE_KEY_DEFAULT      "Shift+Return"
+#define SCIM_PRIME_CONFIG_CONVERT_KEY_DEFAULT                 "space,Control+l,Control+L,Down"
 #define SCIM_PRIME_CONFIG_CANCEL_KEY_DEFAULT                  "Escape,Control+g,Control+G"
+#define SCIM_PRIME_CONFIG_SELECT_PREDICTION_KEY_DEFAULT       "Tab"
 #define SCIM_PRIME_CONFIG_BACKSPACE_KEY_DEFAULT               "BackSpace,Control+h,Control+H"
 #define SCIM_PRIME_CONFIG_DELETE_KEY_DEFAULT                  "Delete,Control+d,Control+D"
 #define SCIM_PRIME_CONFIG_SPACE_KEY_DEFAULT                   "space"
@@ -89,8 +111,8 @@
 #define SCIM_PRIME_CONFIG_MODIFY_CARET_RIGHT_EDGE_KEY_DEFAULT "Control+e,Control+E,End"
 #define SCIM_PRIME_CONFIG_MODIFY_CARET_LEFT_KEY_DEFAULT       "Left,Control+b,Control+B"
 #define SCIM_PRIME_CONFIG_MODIFY_CARET_RIGHT_KEY_DEFAULT      "Right,Control+f,Control+F"
-#define SCIM_PRIME_CONFIG_CONV_NEXT_CANDIDATE_KEY_DEFAULT     "space,Down,KP_Add,Control+n,Control+N"
-#define SCIM_PRIME_CONFIG_CONV_PREV_CANDIDATE_KEY_DEFAULT     "Up,KP_Subtract,Control+p,Control+P"
+#define SCIM_PRIME_CONFIG_CONV_NEXT_CANDIDATE_KEY_DEFAULT     "space,Tab,Down,KP_Add,Control+n,Control+N"
+#define SCIM_PRIME_CONFIG_CONV_PREV_CANDIDATE_KEY_DEFAULT     "Shift+Tab,Up,KP_Subtract,Control+p,Control+P"
 #define SCIM_PRIME_CONFIG_CONV_NEXT_PAGE_KEY_DEFAULT          "Page_Up"
 #define SCIM_PRIME_CONFIG_CONV_PREV_PAGE_KEY_DEFAULT          "Page_Down"
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_1_KEY_DEFAULT      "1"
@@ -103,6 +125,12 @@
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_8_KEY_DEFAULT      "8"
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_9_KEY_DEFAULT      "9"
 #define SCIM_PRIME_CONFIG_SELECT_CANDIDATE_10_KEY_DEFAULT     "10"
+#define SCIM_PRIME_CONFIG_SELECT_FIRST_SEGMENT_KEY_DEFAULT    "Control+a,Control+A,Home"
+#define SCIM_PRIME_CONFIG_SELECT_LAST_SEGMENT_KEY_DEFAULT     "Control+e,Control+E,End"
+#define SCIM_PRIME_CONFIG_SELECT_NEXT_SEGMENT_KEY_DEFAULT     "Right,Control+f,Control+F"
+#define SCIM_PRIME_CONFIG_SELECT_PREV_SEGMENT_KEY_DEFAULT     "Left,Control+b,Control+B"
+#define SCIM_PRIME_CONFIG_SHRINK_SEGMENT_KEY_DEFAULT          "Shift+Left,Control+i,Control+I"
+#define SCIM_PRIME_CONFIG_EXPAND_SEGMENT_KEY_DEFAULT          "Shift+Right,Control+o,Control+O"
 #define SCIM_PRIME_CONFIG_SET_MODE_DEFAULT_KEY_DEFAULT        "F6"
 #define SCIM_PRIME_CONFIG_SET_MODE_KATAKANA_KEY_DEFAULT       "F7"
 #define SCIM_PRIME_CONFIG_SET_MODE_HALF_KATAKANA_KEY_DEFAULT  "F8"
